mvQCAbinTest: A Simple Binomial Test for Type I Error in mvQCA

View source: R/mvQCAbinTest.R

mvQCAbinTestR Documentation

A Simple Binomial Test for Type I Error in mvQCA

Description

A Binomial test for multi-value qualitative comparative analysis (mvQCA), designed to calculate the probability of a false positive given the number of hypotheses implicitly tested and the number of confirming cases.

Usage

mvQCAbinTest(freq.y, configs, total.configs, adj.method = "holm")

Arguments

freq.y

The frequency with which the dependent variable occurs in the sample (the number of 1s divided by the total number of cases).

configs

A list of configurations and the number of cases in which each configuration occurs.

total.configs

The total number of configurations used in the original mvQCA analysis. This will generally equal the number of lines in the truth table used for Boolean minimization.

adj.method

The method used to calculate adjusted p-values (see stats::p.adjust() for details).

Value

An object containing the results of the Binomial test.

Note

Adopted from the archived CRAN package QCAfalsePositive by Bear Braumoeller. The original package has been removed from CRAN and is no longer maintained. It is included in drhutools for continued accessibility.

Examples

test <- mvQCAbinTest(freq.y=0.7, configs=list(aB=5, bCD=3, Ce=2),
   total.configs=20)
summary(test)

drhutools documentation built on June 4, 2026, 9:08 a.m.