p.threshold.adjust: Calculate Vector of p-value Thresholds for Multiple Inference

View source: R/p.threshold.adjust.R

p.threshold.adjustR Documentation

Calculate Vector of p-value Thresholds for Multiple Inference

Description

Internal function. Calculates the adjusted thresholds for multiple significance tests, assuming that the original threshold for a single test is p<0.05. Used by fsQCApermTest() to calculate confidence intervals.

Usage

p.threshold.adjust(total.configs, my.method)

Arguments

total.configs

The total number of hypotheses tested, or the number of configurations utilized by the Quine-McCluskey algorithm in fsQCA (including logical remainders, if they are used in the analysis).

my.method

The adjustment method used to calculate p-values (see stats::p.adjust() for details).

Value

Numeric vector giving adjusted p-value thresholds, from smallest to largest.

Note

Adopted from the archived CRAN package QCAfalsePositive by Bear Braumoeller. The original package has been removed from CRAN and is no longer maintained. It is included in drhutools for continued accessibility.

Examples

p.threshold.adjust(10, "holm")

drhutools documentation built on June 4, 2026, 9:08 a.m.