plot.fsQCApt: Plot Results of fsQCA Permutation Test

View source: R/plot.fsQCApt.R

plot.fsQCAptR Documentation

Plot Results of fsQCA Permutation Test

Description

Plots distributions of consistencies and counterexamples from permutation tests of fsQCA data, including confidence intervals adjusted to account for multiple inference. Also prints observed consistency values and number of counterexamples as black dots along the x-axis, for comparison.

Usage

## S3 method for class 'fsQCApt'
plot(x, y = x$config.names, statistic = "both", ...)

Arguments

x

Object returned by fsQCApermTest().

y

A vector of configurations to examine. Default behavior is to examine all configurations.

statistic

The statistic to examine (consistency, counterexamples, or both).

...

Additional parameters to pass on.

Value

Plots of distributions of consistencies, counterexamples, or both.

Note

Adopted from the archived CRAN package QCAfalsePositive by Bear Braumoeller. The original package has been removed from CRAN and is no longer maintained. It is included in drhutools for continued accessibility.

Examples


intersect  <- pmin(social.revolutions$breakdown, social.revolutions$pop.ins)
intersect2 <- pmin(social.revolutions$breakdown, (1 - social.revolutions$pop.ins))
intersect3 <- pmin((1 - social.revolutions$breakdown), social.revolutions$pop.ins)
intersect4 <- pmin((1 - social.revolutions$breakdown), (1 - social.revolutions$pop.ins))

test <- fsQCApermTest(y = social.revolutions$soc.rev,
  configs = list(BI = intersect, Bi = intersect2,
                 bI = intersect3, bi = intersect4),
  total.configs = 4)
plot(test)
plot(test, "bi", statistic = "consistency")
plot(test, c("BI", "Bi"), statistic = "both")
plot(test, statistic = "consistency")
plot(test, "BI")


drhutools documentation built on June 4, 2026, 9:08 a.m.