summary.fsQCApt: Summarize Permutation Tests for fsQCA Data

View source: R/summary.fsQCApt.R

summary.fsQCAptR Documentation

Summarize Permutation Tests for fsQCA Data

Description

Displays observed values, confidence intervals, and raw and adjusted p-scores for both consistency and counterexamples following permutation test of fsQCA data.

Usage

## S3 method for class 'fsQCApt'
summary(object, ...)

Arguments

object

Object returned by fsQCApermTest().

...

Additional parameters to pass on.

Value

Two matrices of values for counterexamples and consistency.

Note

Adopted from the archived CRAN package QCAfalsePositive by Bear Braumoeller. The original package has been removed from CRAN and is no longer maintained. It is included in drhutools for continued accessibility.

Examples


intersect  <- pmin(social.revolutions$breakdown, social.revolutions$pop.ins)
intersect2 <- pmin(social.revolutions$breakdown, (1 - social.revolutions$pop.ins))
intersect3 <- pmin((1 - social.revolutions$breakdown), social.revolutions$pop.ins)
intersect4 <- pmin((1 - social.revolutions$breakdown), (1 - social.revolutions$pop.ins))

test <- fsQCApermTest(y = social.revolutions$soc.rev,
  configs = list(BI = intersect, Bi = intersect2,
                 bI = intersect3, bi = intersect4),
  total.configs = 4)
summary(test)


drhutools documentation built on June 4, 2026, 9:08 a.m.