View source: R/fsQCApermTest.R
| fsQCApermTest | R Documentation |
A permutation test for fuzzy-set qualitative comparative analysis (fsQCA), designed to calculate the probability of a false positive given the number of hypotheses implicitly tested and the distribution of the data.
fsQCApermTest(
y,
configs,
total.configs,
num.iter = 10000,
my.seed = 123,
adj.method = "holm"
)
y |
The outcome variable of interest. |
configs |
A list of configurations to be tested against |
total.configs |
The total number of configurations used in the original fsQCA analysis. This will generally equal the number of lines in the truth table used for Boolean minimization. |
num.iter |
The number of iterations to use for the permutation test. Larger numbers of iterations result in more precise p-values. |
my.seed |
The seed used to generate random numbers. |
adj.method |
The method used to calculate adjusted p-values (see
|
An object containing the aggregate results of the permutation test as well as the individual permutations.
Adopted from the archived CRAN package QCAfalsePositive by Bear Braumoeller. The original package has been removed from CRAN and is no longer maintained. It is included in drhutools for continued accessibility.
intersect <- pmin(social.revolutions$breakdown, social.revolutions$pop.ins)
intersect2 <- pmin(social.revolutions$breakdown, (1 - social.revolutions$pop.ins))
intersect3 <- pmin((1 - social.revolutions$breakdown), social.revolutions$pop.ins)
intersect4 <- pmin((1 - social.revolutions$breakdown), (1 - social.revolutions$pop.ins))
test <- fsQCApermTest(y = social.revolutions$soc.rev,
configs = list(BI = intersect, Bi = intersect2,
bI = intersect3, bi = intersect4),
total.configs = 4)
summary(test)
plot(test)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.