| mvQCAbinTest | R Documentation |
A Binomial test for multi-value qualitative comparative analysis (mvQCA), designed to calculate the probability of a false positive given the number of hypotheses implicitly tested and the number of confirming cases.
mvQCAbinTest(freq.y, configs, total.configs, adj.method = "holm")
freq.y |
The frequency with which the dependent variable occurs in the sample (the number of 1s divided by the total number of cases). |
configs |
A list of configurations and the number of cases in which each configuration occurs. |
total.configs |
The total number of configurations used in the original mvQCA analysis. This will generally equal the number of lines in the truth table used for Boolean minimization. |
adj.method |
The method used to calculate adjusted p-values (see
|
An object containing the results of the Binomial test.
Adopted from the archived CRAN package QCAfalsePositive by Bear Braumoeller. The original package has been removed from CRAN and is no longer maintained. It is included in drhutools for continued accessibility.
test <- mvQCAbinTest(freq.y=0.7, configs=list(aB=5, bCD=3, Ce=2),
total.configs=20)
summary(test)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.