View source: R/p.threshold.adjust.R
| p.threshold.adjust | R Documentation |
Internal function. Calculates the adjusted thresholds for multiple significance
tests, assuming that the original threshold for a single test is p<0.05.
Used by fsQCApermTest() to calculate confidence intervals.
p.threshold.adjust(total.configs, my.method)
total.configs |
The total number of hypotheses tested, or the number of configurations utilized by the Quine-McCluskey algorithm in fsQCA (including logical remainders, if they are used in the analysis). |
my.method |
The adjustment method used to calculate p-values (see
|
Numeric vector giving adjusted p-value thresholds, from smallest to largest.
Adopted from the archived CRAN package QCAfalsePositive by Bear Braumoeller. The original package has been removed from CRAN and is no longer maintained. It is included in drhutools for continued accessibility.
p.threshold.adjust(10, "holm")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.