| plot.fsQCApt | R Documentation |
Plots distributions of consistencies and counterexamples from permutation tests of fsQCA data, including confidence intervals adjusted to account for multiple inference. Also prints observed consistency values and number of counterexamples as black dots along the x-axis, for comparison.
## S3 method for class 'fsQCApt'
plot(x, y = x$config.names, statistic = "both", ...)
x |
Object returned by |
y |
A vector of configurations to examine. Default behavior is to examine all configurations. |
statistic |
The statistic to examine ( |
... |
Additional parameters to pass on. |
Plots of distributions of consistencies, counterexamples, or both.
Adopted from the archived CRAN package QCAfalsePositive by Bear Braumoeller. The original package has been removed from CRAN and is no longer maintained. It is included in drhutools for continued accessibility.
intersect <- pmin(social.revolutions$breakdown, social.revolutions$pop.ins)
intersect2 <- pmin(social.revolutions$breakdown, (1 - social.revolutions$pop.ins))
intersect3 <- pmin((1 - social.revolutions$breakdown), social.revolutions$pop.ins)
intersect4 <- pmin((1 - social.revolutions$breakdown), (1 - social.revolutions$pop.ins))
test <- fsQCApermTest(y = social.revolutions$soc.rev,
configs = list(BI = intersect, Bi = intersect2,
bI = intersect3, bi = intersect4),
total.configs = 4)
plot(test)
plot(test, "bi", statistic = "consistency")
plot(test, c("BI", "Bi"), statistic = "both")
plot(test, statistic = "consistency")
plot(test, "BI")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.