View source: R/summary.fsQCApt.R
| summary.fsQCApt | R Documentation |
Displays observed values, confidence intervals, and raw and adjusted p-scores for both consistency and counterexamples following permutation test of fsQCA data.
## S3 method for class 'fsQCApt'
summary(object, ...)
object |
Object returned by |
... |
Additional parameters to pass on. |
Two matrices of values for counterexamples and consistency.
Adopted from the archived CRAN package QCAfalsePositive by Bear Braumoeller. The original package has been removed from CRAN and is no longer maintained. It is included in drhutools for continued accessibility.
intersect <- pmin(social.revolutions$breakdown, social.revolutions$pop.ins)
intersect2 <- pmin(social.revolutions$breakdown, (1 - social.revolutions$pop.ins))
intersect3 <- pmin((1 - social.revolutions$breakdown), social.revolutions$pop.ins)
intersect4 <- pmin((1 - social.revolutions$breakdown), (1 - social.revolutions$pop.ins))
test <- fsQCApermTest(y = social.revolutions$soc.rev,
configs = list(BI = intersect, Bi = intersect2,
bI = intersect3, bi = intersect4),
total.configs = 4)
summary(test)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.